@@ -40,7 +40,7 @@ from collections import (
 )
 from logging import getLogger
 from random import choice
-from select import select
+import selectors
 from socket import (
     AF_INET,
     AF_INET6,
@@ -1262,8 +1262,9 @@ def _handshake(s, resolved_address):
 
     # Handle the handshake response
     ready_to_read = False
-    while not ready_to_read:
-        ready_to_read, _, _ = select((s,), (), (), 1)
+    with selectors.DefaultSelector() as selector:
+        selector.register(s, selectors.EVENT_READ)
+        selector.select(1)
     try:
         data = s.recv(4)
     except OSError:
@@ -1316,6 +1317,14 @@ def connect(address, *, timeout, custom_resolver, ssl_context, keep_alive):
             s = _secure(s, resolved_address.host_name, ssl_context)
             return _handshake(s, resolved_address)
         except (BoltError, DriverError, OSError) as error:
+            try:
+                local_port = s.getsockname()[1]
+            except (OSError, AttributeError):
+                local_port = 0
+            err_str = error.__class__.__name__
+            if str(error):
+                err_str += ": " + str(error)
+            log.debug("[#%04X]  C: <CONNECTION FAILED> %s", local_port, err_str)
             if s:
                 _close_socket(s)
             errors.append(error)
